@@ -1,9 +1,8 @@
+use std::io::ErrorKind;
 use std::io::Read;
+use std::io::Result;
 use std::io::Write;
 
-use anyhow::bail;
-use anyhow::Result;
-
 const SUCCESS_BYTES: &[u8; 4] = &[255, 255, 255, 255];
 
 pub struct MessageReader<TRead: Read + Unpin> {
@@ -43,12 +42,14 @@ impl<TRead: Read + Unpin> MessageReader<TRead> {
   pub fn read_success_bytes(&mut self) -> Result<()> {
     let read_bytes = self.inner_read_success_bytes()?;
     if &read_bytes != SUCCESS_BYTES {
-      bail!(
+      let message = format!(
         "Catastrophic error reading from process. Did not receive the success bytes at end of message. Found: {:?}",
         read_bytes
-      )
+      );
+      Result::Err(std::io::Error::new(ErrorKind::InvalidData, message))
+    } else {
+      Ok(())
     }
-    Ok(())
   }
 
   fn inner_read_success_bytes(&mut self) -> Result<[u8; 4]> {
@@ -87,6 +88,6 @@ impl<TWrite: Write + Unpin> MessageWriter<TWrite> {
   }
 
   pub fn flush(&mut self) -> Result<()> {
-    Ok(self.writer.flush()?)
+    self.writer.flush()
   }
 }
