@@ -1,7 +1,7 @@
 mod graph_node;
-mod rc_stack;
+mod node_stack;
 mod vec_u32_map;
 
 pub use graph_node::*;
-pub use rc_stack::*;
+pub use node_stack::*;
 pub use vec_u32_map::*;
