@@ -1,14 +1,16 @@
-use bumpalo::Bump;
-use rustc_hash::FxHashMap;
+use std::hash::BuildHasherDefault;
+
+type BumpHashMap<'a, K, V> = hashbrown::HashMap<K, V, BuildHasherDefault<rustc_hash::FxHasher>, &'a bumpalo::Bump>;
 
 use super::collections::*;
 use super::infinite_reevaluation_protection::InfiniteReevaluationProtector;
 use super::print_items::*;
 use super::thread_state;
+use super::thread_state::BumpAllocator;
 use super::writer::*;
 use super::WriteItem;
 
-struct SavePoint<'a> {
+pub struct SavePoint<'a> {
   #[cfg(debug_assertions)]
   /// Name for debugging purposes.
   pub name: &'static str,
@@ -17,14 +19,14 @@ struct SavePoint<'a> {
   pub writer_state: WriterState<'a>,
   pub possible_new_line_save_point: Option<&'a SavePoint<'a>>,
   pub node: Option<PrintItemPath>,
-  pub look_ahead_condition_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_line_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_column_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_is_start_of_line_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_indent_level_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_line_start_column_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub look_ahead_line_start_indent_level_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  pub next_node_stack: RcStack,
+  pub look_ahead_condition_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_line_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_column_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_is_start_of_line_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_indent_level_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_line_start_column_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub look_ahead_line_start_indent_level_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  pub next_node_stack: NodeStack<'a>,
 }
 
 struct PrintItemContainer<'a> {
@@ -58,14 +60,14 @@ pub struct PrinterOptions {
 }
 
 pub struct Printer<'a> {
-  bump: &'a Bump,
+  bump: &'a BumpAllocator,
   possible_new_line_save_point: Option<&'a SavePoint<'a>>,
   new_line_group_depth: u16,
   force_no_newlines_depth: u8,
   current_node: Option<PrintItemPath>,
   writer: Writer<'a>,
-  // Use a regular hash map here because only some conditions are stored (not all).
-  resolved_conditions: FxHashMap<u32, Option<bool>>,
+  // Use a hash map here because only some conditions are stored (not all).
+  resolved_conditions: BumpHashMap<'a, u32, Option<bool>>,
   // Use these "VecU32Map" for resolved infos because it has much faster
   // lookups than a hash map and generally infos seem to be resolved
   // about 90% of the time, so the extra memory usage is probably not
@@ -77,16 +79,16 @@ pub struct Printer<'a> {
   resolved_indent_levels: VecU32U8Map,
   resolved_line_start_column_numbers: VecU32U32Map,
   resolved_line_start_indent_levels: VecU32U8Map,
-  look_ahead_condition_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_line_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_column_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_is_start_of_line_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_indent_level_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_line_start_column_number_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
-  look_ahead_line_start_indent_level_save_points: FxHashMap<u32, &'a SavePoint<'a>>,
+  look_ahead_condition_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_line_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_column_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_is_start_of_line_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_indent_level_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_line_start_column_number_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
+  look_ahead_line_start_indent_level_save_points: BumpHashMap<'a, u32, &'a SavePoint<'a>>,
   infinite_reevaluation_protector: InfiniteReevaluationProtector,
-  next_node_stack: RcStack,
-  stored_condition_save_points: FxHashMap<u32, (&'a Condition, &'a SavePoint<'a>)>,
+  next_node_stack: NodeStack<'a>,
+  stored_condition_save_points: BumpHashMap<'a, u32, (&'a Condition, &'a SavePoint<'a>)>,
   max_width: u32,
   skip_moving_next: bool,
   resolving_save_point: Option<&'a SavePoint<'a>>,
@@ -97,7 +99,7 @@ pub struct Printer<'a> {
 }
 
 impl<'a> Printer<'a> {
-  pub fn new(bump: &'a Bump, start_node: Option<PrintItemPath>, options: PrinterOptions) -> Printer<'a> {
+  pub fn new(bump: &'a BumpAllocator, start_node: Option<PrintItemPath>, options: PrinterOptions) -> Printer<'a> {
     Printer {
       bump,
       possible_new_line_save_point: None,
@@ -112,7 +114,7 @@ impl<'a> Printer<'a> {
           enable_tracing: options.enable_tracing,
         },
       ),
-      resolved_conditions: FxHashMap::default(),
+      resolved_conditions: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
       resolved_line_number_anchors: VecU32U32Map::with_capacity(thread_state::next_line_number_anchor_id()),
       resolved_line_numbers: VecU32U32Map::with_capacity(thread_state::next_line_number_id()),
       resolved_column_numbers: VecU32U32Map::with_capacity(thread_state::next_column_number_id()),
@@ -120,16 +122,16 @@ impl<'a> Printer<'a> {
       resolved_indent_levels: VecU32U8Map::with_capacity(thread_state::next_indent_level_id()),
       resolved_line_start_column_numbers: VecU32U32Map::with_capacity(thread_state::next_line_start_column_number_id()),
       resolved_line_start_indent_levels: VecU32U8Map::with_capacity(thread_state::next_line_start_indent_level_id()),
-      look_ahead_condition_save_points: FxHashMap::default(),
-      look_ahead_line_number_save_points: FxHashMap::default(),
-      look_ahead_column_number_save_points: FxHashMap::default(),
-      look_ahead_is_start_of_line_save_points: FxHashMap::default(),
-      look_ahead_indent_level_save_points: FxHashMap::default(),
-      look_ahead_line_start_column_number_save_points: FxHashMap::default(),
-      look_ahead_line_start_indent_level_save_points: FxHashMap::default(),
+      look_ahead_condition_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_line_number_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_column_number_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_is_start_of_line_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_indent_level_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_line_start_column_number_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      look_ahead_line_start_indent_level_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
       infinite_reevaluation_protector: InfiniteReevaluationProtector::with_capacity(thread_state::next_condition_reevaluation_id()),
-      stored_condition_save_points: FxHashMap::default(),
-      next_node_stack: RcStack::default(),
+      stored_condition_save_points: BumpHashMap::with_hasher_in(Default::default(), bump.inner()),
+      next_node_stack: NodeStack::default(),
       max_width: options.max_width,
       skip_moving_next: false,
       resolving_save_point: None,
@@ -316,7 +318,7 @@ impl<'a> Printer<'a> {
   }
 
   fn create_save_point(&self, _name: &'static str, next_node: Option<PrintItemPath>) -> &'a SavePoint<'a> {
-    self.bump.alloc(SavePoint {
+    self.bump.alloc_save_point(SavePoint {
       #[cfg(debug_assertions)]
       name: _name,
       possible_new_line_save_point: self.possible_new_line_save_point,
@@ -570,14 +572,14 @@ impl<'a> Printer<'a> {
       if let Some(true_path) = condition.true_path {
         self.current_node = Some(true_path);
         if let Some(path) = next_node {
-          self.next_node_stack.push(path);
+          self.next_node_stack.push(path, self.bump);
         }
         self.skip_moving_next = true;
       }
     } else if let Some(false_path) = condition.false_path {
       self.current_node = Some(false_path);
       if let Some(path) = next_node {
-        self.next_node_stack.push(path);
+        self.next_node_stack.push(path, self.bump);
       }
       self.skip_moving_next = true;
     }
@@ -586,7 +588,7 @@ impl<'a> Printer<'a> {
   #[inline]
   fn handle_rc_path(&mut self, print_item_path: &PrintItemPath, next_node: &Option<PrintItemPath>) {
     if let Some(path) = next_node {
-      self.next_node_stack.push(path);
+      self.next_node_stack.push(path, self.bump);
     }
     self.current_node = Some(print_item_path);
     self.skip_moving_next = true;
@@ -595,7 +597,7 @@ impl<'a> Printer<'a> {
   #[inline]
   fn handle_string(&mut self, text: &'a StringContainer) {
     #[cfg(debug_assertions)]
-    self.validate_string(&text.text);
+    self.validate_string(text.text);
 
     if self.possible_new_line_save_point.is_some() && self.is_above_max_width(text.char_count) && self.allow_new_lines() {
       let save_point = self.possible_new_line_save_point.take();
