@@ -102,7 +102,7 @@ impl ProcessPluginMessage {
             })
           },
           config_id,
-          file_text,
+          file_bytes: file_text,
           override_config,
         })
       }
@@ -219,10 +219,10 @@ impl Message for ProcessPluginMessage {
         writer.send_u32(message_ids::FORMAT_ID)?;
         writer.send_sized_bytes(body.file_path.to_string_lossy().as_bytes())?;
         writer.send_u32(body.range.as_ref().map(|r| r.start).unwrap_or(0) as u32)?;
-        writer.send_u32(body.range.as_ref().map(|r| r.end).unwrap_or(body.file_text.len()) as u32)?;
+        writer.send_u32(body.range.as_ref().map(|r| r.end).unwrap_or(body.file_bytes.len()) as u32)?;
         writer.send_u32(body.config_id.as_raw())?;
         writer.send_sized_bytes(&body.override_config)?;
-        writer.send_sized_bytes(&body.file_text)?;
+        writer.send_sized_bytes(&body.file_bytes)?;
       }
       MessageBody::FormatResponse(response) => {
         writer.send_u32(message_ids::FORMAT_RESPONSE_ID)?;
@@ -312,7 +312,7 @@ pub struct FormatMessageBody {
   pub range: FormatRange,
   pub config_id: FormatConfigId,
   pub override_config: Vec<u8>,
-  pub file_text: Vec<u8>,
+  pub file_bytes: Vec<u8>,
 }
 
 #[derive(Debug)]
