@@ -56,18 +56,53 @@ pub enum SubCommand {
   Help(String),
   EditorInfo,
   EditorService(EditorServiceSubCommand),
+  Lsp,
   StdInFmt(StdInFmtSubCommand),
   Completions(clap_complete::Shell),
   Upgrade,
   #[cfg(target_os = "windows")]
   Hidden(HiddenSubCommand),
 }
+impl SubCommand {
+  pub fn allow_no_files(&self) -> bool {
+    match self {
+      SubCommand::Check(a) => a.allow_no_files,
+      SubCommand::Fmt(a) => a.allow_no_files,
+      SubCommand::OutputFormatTimes(a) => a.allow_no_files,
+      _ => false,
+    }
+  }
+
+  pub fn file_patterns(&self) -> Option<&FilePatternArgs> {
+    match self {
+      SubCommand::Check(a) => Some(&a.patterns),
+      SubCommand::Fmt(a) => Some(&a.patterns),
+      SubCommand::StdInFmt(a) => Some(&a.patterns),
+      SubCommand::OutputFilePaths(a) => Some(&a.patterns),
+      SubCommand::OutputFormatTimes(a) => Some(&a.patterns),
+      SubCommand::Config(_)
+      | SubCommand::ClearCache
+      | SubCommand::OutputResolvedConfig
+      | SubCommand::Version
+      | SubCommand::License
+      | SubCommand::Help(_)
+      | SubCommand::Lsp
+      | SubCommand::EditorInfo
+      | SubCommand::EditorService(_)
+      | SubCommand::Completions(_)
+      | SubCommand::Upgrade => None,
+      #[cfg(target_os = "windows")]
+      SubCommand::Hidden(_) => None,
+    }
+  }
+}
 
 #[derive(Debug, PartialEq, Eq)]
 pub struct CheckSubCommand {
   pub patterns: FilePatternArgs,
   pub incremental: Option<bool>,
   pub list_different: bool,
+  pub allow_no_files: bool,
 }
 
 #[derive(Debug, PartialEq, Eq)]
@@ -76,6 +111,7 @@ pub struct FmtSubCommand {
   pub patterns: FilePatternArgs,
   pub incremental: Option<bool>,
   pub enable_stable_format: bool,
+  pub allow_no_files: bool,
 }
 
 #[derive(Debug, PartialEq, Eq)]
@@ -93,6 +129,7 @@ pub struct OutputFilePathsSubCommand {
 #[derive(Debug, PartialEq, Eq)]
 pub struct OutputFormatTimesSubCommand {
   pub patterns: FilePatternArgs,
+  pub allow_no_files: bool,
 }
 
 #[derive(Debug, PartialEq, Eq)]
@@ -103,7 +140,7 @@ pub struct EditorServiceSubCommand {
 #[derive(Debug, PartialEq, Eq)]
 pub struct StdInFmtSubCommand {
   pub file_name_or_path: String,
-  pub file_text: String,
+  pub file_bytes: Vec<u8>,
   pub patterns: FilePatternArgs,
 }
 
@@ -118,8 +155,10 @@ pub enum HiddenSubCommand {
 
 #[derive(Debug, Default, PartialEq, Eq)]
 pub struct FilePatternArgs {
-  pub file_patterns: Vec<String>,
-  pub exclude_file_patterns: Vec<String>,
+  pub include_patterns: Vec<String>,
+  pub include_pattern_overrides: Option<Vec<String>>,
+  pub exclude_patterns: Vec<String>,
+  pub exclude_pattern_overrides: Option<Vec<String>>,
   pub allow_node_modules: bool,
 }
 
@@ -159,7 +198,7 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
         };
         SubCommand::StdInFmt(StdInFmtSubCommand {
           file_name_or_path,
-          file_text: std_in_reader.read()?,
+          file_bytes: std_in_reader.read()?,
           patterns: parse_file_patterns(matches)?,
         })
       } else {
@@ -168,6 +207,7 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
           patterns: parse_file_patterns(matches)?,
           incremental: parse_incremental(matches),
           enable_stable_format: !matches.get_flag("skip-stable-format"),
+          allow_no_files: matches.get_flag("allow-no-files"),
         })
       }
     }
@@ -175,6 +215,7 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
       patterns: parse_file_patterns(matches)?,
       incremental: parse_incremental(matches),
       list_different: matches.get_flag("list-different"),
+      allow_no_files: matches.get_flag("allow-no-files"),
     }),
     ("init", _) => SubCommand::Config(ConfigSubCommand::Init),
     ("config", matches) => SubCommand::Config(match matches.subcommand().unwrap() {
@@ -192,6 +233,7 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
     ("output-resolved-config", _) => SubCommand::OutputResolvedConfig,
     ("output-format-times", matches) => SubCommand::OutputFormatTimes(OutputFormatTimesSubCommand {
       patterns: parse_file_patterns(matches)?,
+      allow_no_files: matches.get_flag("allow-no-files"),
     }),
     ("version", _) => SubCommand::Version,
     ("license", _) => SubCommand::License,
@@ -199,6 +241,7 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
     ("editor-service", matches) => SubCommand::EditorService(EditorServiceSubCommand {
       parent_pid: matches.get_one::<String>("parent-pid").and_then(|v| v.parse::<u32>().ok()).unwrap(),
     }),
+    ("lsp", _) => SubCommand::Lsp,
     ("completions", matches) => SubCommand::Completions(matches.get_one::<clap_complete::Shell>("shell").unwrap().to_owned()),
     ("upgrade", _) => SubCommand::Upgrade,
     #[cfg(target_os = "windows")]
@@ -229,13 +272,13 @@ fn inner_parse_args<TStdInReader: StdInReader>(args: Vec<String>, std_in_reader:
       LogLevel::Info
     },
     config: matches.get_one::<String>("config").map(String::from),
-    plugins: values_to_vec(matches.get_many("plugins")),
+    plugins: maybe_values_to_vec(matches.get_many("plugins")),
   })
 }
 
 fn parse_file_patterns(matches: &ArgMatches) -> Result<FilePatternArgs> {
-  let plugins = values_to_vec(matches.get_many("plugins"));
-  let file_patterns = values_to_vec(matches.get_many("files"));
+  let plugins = maybe_values_to_vec(matches.get_many("plugins"));
+  let file_patterns = maybe_values_to_vec(matches.get_many("files"));
 
   if !plugins.is_empty() && file_patterns.is_empty() {
     validate_plugin_args_when_no_files(&plugins)?;
@@ -243,8 +286,10 @@ fn parse_file_patterns(matches: &ArgMatches) -> Result<FilePatternArgs> {
 
   Ok(FilePatternArgs {
     allow_node_modules: matches.get_flag("allow-node-modules"),
-    file_patterns,
-    exclude_file_patterns: values_to_vec(matches.get_many("excludes")),
+    include_patterns: file_patterns,
+    include_pattern_overrides: matches.get_many("includes-override").map(values_to_vec),
+    exclude_patterns: maybe_values_to_vec(matches.get_many("excludes")),
+    exclude_pattern_overrides: matches.get_many("excludes-override").map(values_to_vec),
   })
 }
 
@@ -258,8 +303,12 @@ fn parse_incremental(matches: &ArgMatches) -> Option<bool> {
   }
 }
 
-fn values_to_vec(values: Option<clap::parser::ValuesRef<String>>) -> Vec<String> {
-  values.map(|x| x.map(std::string::ToString::to_string).collect()).unwrap_or_default()
+fn maybe_values_to_vec(values: Option<clap::parser::ValuesRef<String>>) -> Vec<String> {
+  values.map(values_to_vec).unwrap_or_default()
+}
+
+fn values_to_vec(values: clap::parser::ValuesRef<String>) -> Vec<String> {
+  values.map(std::string::ToString::to_string).collect()
 }
 
 /// Users have accidentally specified: dprint fmt --plugins <url1> <url2> -- <file-path>
@@ -386,6 +435,7 @@ EXAMPLES:
             .num_args(0)
             .required(false)
         )
+        .add_allow_no_files_arg()
         .arg(
           Arg::new("skip-stable-format")
             .long("skip-stable-format")
@@ -401,6 +451,7 @@ EXAMPLES:
         .about("Checks for any files that haven't been formatted.")
         .add_resolve_file_path_args()
         .add_incremental_arg()
+        .add_allow_no_files_arg()
         .arg(
           Arg::new("list-different")
             .long("list-different")
@@ -444,6 +495,7 @@ EXAMPLES:
       Command::new("output-format-times")
         .about("Prints the amount of time it takes to format each file. Use this for debugging.")
         .add_resolve_file_path_args()
+        .add_allow_no_files_arg()
     )
     .subcommand(
       Command::new("clear-cache")
@@ -479,6 +531,10 @@ EXAMPLES:
             .num_args(1)
         )
     )
+    .subcommand(
+      Command::new("lsp")
+      .about("Starts up a language server for formatting files.")
+    )
     .arg(
       Arg::new("config")
         .long("config")
@@ -530,6 +586,7 @@ EXAMPLES:
 trait ClapExtensions {
   fn add_resolve_file_path_args(self) -> Self;
   fn add_incremental_arg(self) -> Self;
+  fn add_allow_no_files_arg(self) -> Self;
 }
 
 impl ClapExtensions for clap::Command {
@@ -538,6 +595,13 @@ impl ClapExtensions for clap::Command {
     self
       .arg(
         Arg::new("files")
+          .help("List of file patterns in quotes to format. This can be a subset of what is found in the config file.")
+          .num_args(1..),
+      )
+      .arg(
+        Arg::new("includes-override")
+          .long("includes-override")
+          .value_name("patterns")
           .help("List of file patterns in quotes to format. This overrides what is specified in the config file.")
           .num_args(1..),
       )
@@ -545,6 +609,13 @@ impl ClapExtensions for clap::Command {
         Arg::new("excludes")
           .long("excludes")
           .value_name("patterns")
+          .help("List of file patterns or directories in quotes to exclude when formatting. This excludes in addition to what is found in the config file.")
+          .num_args(1..),
+      )
+      .arg(
+        Arg::new("excludes-override")
+          .long("excludes-override")
+          .value_name("patterns")
           .help("List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file.")
           .num_args(1..),
       )
@@ -567,6 +638,17 @@ impl ClapExtensions for clap::Command {
         .require_equals(true),
     )
   }
+
+  fn add_allow_no_files_arg(self) -> Self {
+    use clap::Arg;
+    self.arg(
+      Arg::new("allow-no-files")
+        .long("allow-no-files")
+        .help("Causes dprint to exit with exit code 0 when no files are found instead of exit code 14.")
+        .num_args(0)
+        .required(false),
+    )
+  }
 }
 
 #[cfg(test)]
