@@ -26,7 +26,7 @@ use crate::resolution::resolve_plugins_scope_and_paths;
 use crate::resolution::PluginsScope;
 use crate::utils::get_difference;
 use crate::utils::AtomicCounter;
-use crate::utils::BOM_CHAR;
+use crate::utils::BOM_BYTES;
 
 pub async fn stdin_fmt<TEnvironment: Environment>(
   cmd: &StdInFmtSubCommand,
@@ -41,28 +41,28 @@ pub async fn stdin_fmt<TEnvironment: Environment>(
 
   // if the path is absolute, then apply exclusion rules
   if environment.is_absolute_path(&cmd.file_name_or_path) {
-    let file_matcher = FileMatcher::new(plugins_scope.config.as_ref().unwrap(), &cmd.patterns, environment)?;
+    let file_matcher = FileMatcher::new(plugins_scope.config.as_ref().unwrap(), &cmd.patterns, &environment.cwd())?;
     // canonicalize the file path, then check if it's in the list of file paths.
     let resolved_file_path = environment.canonicalize(&cmd.file_name_or_path)?;
     // log the file text as-is since it's not in the list of files to format
     if !file_matcher.matches(resolved_file_path) {
-      environment.log_machine_readable(&cmd.file_text);
+      environment.log_machine_readable(&cmd.file_bytes);
       return Ok(());
     }
   }
-  output_stdin_format(PathBuf::from(&cmd.file_name_or_path), &cmd.file_text, plugins_scope, environment).await
+  output_stdin_format(PathBuf::from(&cmd.file_name_or_path), &cmd.file_bytes, plugins_scope, environment).await
 }
 
 async fn output_stdin_format<TEnvironment: Environment>(
-  file_name: PathBuf,
-  file_text: &str,
+  file_path: PathBuf,
+  file_bytes: &[u8],
   plugins_scope: Rc<PluginsScope<TEnvironment>>,
   environment: &TEnvironment,
 ) -> Result<()> {
   let result = plugins_scope
     .format(HostFormatRequest {
-      file_path: file_name,
-      file_text: file_text.to_string(),
+      file_path,
+      file_bytes: file_bytes.to_vec(),
       range: None,
       override_config: Default::default(),
       token: Arc::new(NullCancellationToken),
@@ -70,7 +70,7 @@ async fn output_stdin_format<TEnvironment: Environment>(
     .await?;
   match result {
     Some(text) => environment.log_machine_readable(&text),
-    None => environment.log_machine_readable(file_text),
+    None => environment.log_machine_readable(file_bytes),
   }
   Ok(())
 }
@@ -140,13 +140,13 @@ pub async fn check<TEnvironment: Environment>(
     run_parallelized(scope_and_paths, environment, incremental_file.clone(), EnsureStableFormat(false), {
       let not_formatted_files_count = not_formatted_files_count.clone();
       let incremental_file = incremental_file.clone();
-      move |file_path, file_text, formatted_text, _, environment| {
-        if formatted_text != file_text.as_str() {
+      move |file_path, file_bytes, formatted_bytes, _, environment| {
+        if formatted_bytes != file_bytes.as_ref() {
           not_formatted_files_count.inc();
           if list_different {
             log_stdout_info!(environment, "{}", file_path.display());
           } else {
-            output_difference(&file_path, file_text.as_str(), &formatted_text, &environment);
+            output_difference(&file_path, file_bytes.as_ref(), &formatted_bytes, &environment);
           }
         } else {
           // update the incremental cache when the file is already formatted correctly
@@ -154,7 +154,7 @@ pub async fn check<TEnvironment: Environment>(
           // correctly formatted file because it hasn't undergone a stable
           // formatting check
           if let Some(incremental_file) = &incremental_file {
-            incremental_file.update_file(&formatted_text);
+            incremental_file.update_file(&formatted_bytes);
           }
         }
         Ok(())
@@ -180,8 +180,32 @@ pub async fn check<TEnvironment: Environment>(
   }
 }
 
-fn output_difference(file_path: &Path, file_text: &str, formatted_text: &str, environment: &impl Environment) {
-  let difference_text = get_difference(file_text, formatted_text);
+fn output_difference(file_path: &Path, file_bytes: &[u8], formatted_bytes: &[u8], environment: &impl Environment) {
+  let file_text = match String::from_utf8(file_bytes.to_vec()) {
+    Ok(text) => text,
+    Err(err) => {
+      log_warn!(
+        environment,
+        "Failed outputting difference for {}. Could not get original text as utf-8. {:#}",
+        file_path.display(),
+        err
+      );
+      return;
+    }
+  };
+  let formatted_text = match String::from_utf8(formatted_bytes.to_vec()) {
+    Ok(text) => text,
+    Err(err) => {
+      log_warn!(
+        environment,
+        "Failed outputting difference for {}. Coult not get formatted text as utf-8. {:#}",
+        file_path.display(),
+        err
+      );
+      return;
+    }
+  };
+  let difference_text = get_difference(&file_text, &formatted_text);
   log_stdout_info!(environment, "{} {}:\n{}\n--", "from".bold().red(), file_path.display(), difference_text);
 }
 
@@ -212,25 +236,28 @@ pub async fn format<TEnvironment: Environment>(
       {
         let formatted_files_count = formatted_files_count.clone();
         let incremental_file = incremental_file.clone();
-        move |file_path, file_text, formatted_text, _, environment| {
+        move |file_path, file_bytes, formatted_bytes, _, environment| {
           if let Some(incremental_file) = &incremental_file {
-            incremental_file.update_file(&formatted_text);
+            incremental_file.update_file(&formatted_bytes);
           }
 
-          if formatted_text != file_text.as_str() {
+          if formatted_bytes != file_bytes.as_ref() {
             if output_diff {
-              output_difference(&file_path, file_text.as_str(), &formatted_text, &environment);
+              output_difference(&file_path, file_bytes.as_ref(), &formatted_bytes, &environment);
             }
 
-            let new_text = if file_text.has_bom() {
+            let new_text = if file_bytes.has_bom() {
               // add back the BOM
-              format!("{}{}", BOM_CHAR, formatted_text)
+              let mut new_bytes = Vec::with_capacity(file_bytes.as_ref().len() + BOM_BYTES.len());
+              new_bytes.extend_from_slice(BOM_BYTES);
+              new_bytes.extend(formatted_bytes);
+              new_bytes
             } else {
-              formatted_text
+              formatted_bytes
             };
 
             formatted_files_count.inc();
-            environment.write_file(file_path, &new_text)?;
+            environment.write_file_bytes(file_path, &new_text)?;
           }
 
           Ok(())
@@ -351,7 +378,7 @@ mod test {
       environment.take_stderr_messages(),
       vec![String::from("Error formatting /file.txt. Message: Did error.")]
     );
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
   }
 
   #[test]
@@ -364,7 +391,7 @@ mod test {
       environment.take_stderr_messages(),
       vec![String::from("Error formatting /file.txt_ps. Message: Did error.")]
     );
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
   }
 
   #[test]
@@ -382,7 +409,7 @@ mod test {
       "This may be a bug in the plugin, the dprint cli is out of date, or the plugin is out of date.",
     );
     assert_eq!(&logged_errors[0][..expected_start_text.len()], expected_start_text);
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     // should still format with the other plugin
     assert_eq!(environment.read_file("/file2.txt_ps").unwrap(), "test_formatted_process");
   }
@@ -438,7 +465,7 @@ mod test {
       .write_file("/file.txt", "plugin: should_error")
       .build();
     let error_message = run_test_cli(vec!["fmt", "/file.txt"], &environment).err().unwrap();
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![String::from("Error formatting /file.txt. Message: Did error.")]
@@ -496,7 +523,7 @@ mod test {
       .write_file("/file.txt_ps", "plugin: should_error")
       .build();
     let error_message = run_test_cli(vec!["fmt", "/file.txt_ps"], &environment).err().unwrap();
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![String::from("Error formatting /file.txt_ps. Message: Did error.")]
@@ -838,7 +865,7 @@ mod test {
 
     let error_message = run_test_cli(vec!["fmt", "**/*.txt"], &environment).err().unwrap();
 
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![
@@ -869,7 +896,7 @@ mod test {
 
     let error_message = run_test_cli(vec!["fmt", "**/*.txt_ps"], &environment).err().unwrap();
 
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![
@@ -910,7 +937,7 @@ mod test {
 
     let error_message = run_test_cli(vec!["fmt", "--config", "/config.json"], &environment).err().unwrap();
 
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![
@@ -1035,13 +1062,34 @@ mod test {
     assert_no_files_found(&error, &environment);
   }
 
+  #[test]
+  fn should_not_error_when_no_files_match_allow_no_files_output() {
+    run_allow_no_files_test("fmt");
+    run_allow_no_files_test("check");
+    run_allow_no_files_test("output-format-times");
+
+    fn run_allow_no_files_test(sub_command: &str) {
+      // with
+      {
+        let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_plugin().build();
+        assert!(run_test_cli(vec![sub_command, "--allow-no-files", "**/*.txt"], &environment).is_ok());
+      }
+      // without
+      {
+        let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_plugin().build();
+        let error = run_test_cli(vec![sub_command, "**/*.txt"], &environment).err().unwrap();
+        assert_no_files_found(&error, &environment);
+      }
+    }
+  }
+
   #[track_caller]
   fn assert_no_files_found(error: &TestAppError, _environment: &TestEnvironment) {
     assert_eq!(
       error.to_string(),
       concat!(
         "No files found to format with the specified plugins at /. ",
-        "You may want to try using `dprint output-file-paths` to see which files it's finding."
+        "You may want to try using `dprint output-file-paths` to see which files it's finding or run with `--allow-no-files`."
       )
     );
     error.assert_exit_code(14);
@@ -1050,7 +1098,7 @@ mod test {
   #[cfg(target_os = "windows")]
   #[test]
   fn should_format_absolute_paths_on_windows() {
-    let file_path = "D:\\test\\other\\file1.txt"; // needs to be in the base directory
+    let file_path = "D:\\test\\other\\asdf\\file1.txt"; // needs to be in the base directory
     let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
       .with_local_config("D:\\test\\other\\dprint.json", |c| {
         c.add_includes("asdf/**/*.txt").add_remote_wasm_plugin();
@@ -1067,10 +1115,10 @@ mod test {
     assert_eq!(environment.read_file(&file_path).unwrap(), "text1_formatted");
   }
 
-  #[cfg(target_os = "linux")]
+  #[cfg(unix)]
   #[test]
-  fn should_format_absolute_paths_on_linux() {
-    let file_path = "/test/other/file1.txt"; // needs to be in the base directory
+  fn should_format_absolute_paths_on_unix() {
+    let file_path = "/test/other/asdf/file1.txt"; // needs to be in the base directory
     let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
       .with_local_config("/test/other/dprint.json", |c| {
         c.add_includes("asdf/**/*.txt").add_remote_wasm_plugin();
@@ -1080,7 +1128,7 @@ mod test {
       .initialize()
       .build();
 
-    run_test_cli(vec!["fmt", "--", "/test/other/file1.txt"], &environment).unwrap();
+    run_test_cli(vec!["fmt", "--", "/test/other/asdf/file1.txt"], &environment).unwrap();
 
     assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
     assert_eq!(environment.read_file(&file_path).unwrap(), "text1_formatted");
@@ -1175,7 +1223,30 @@ mod test {
   }
 
   #[test]
-  fn should_override_config_excludes_with_cli_excludes() {
+  fn should_combine_config_excludes_with_cli_excludes() {
+    let file_path1 = "/file1.txt";
+    let file_path2 = "/file2.txt";
+    let file_path3 = "/file3.txt";
+    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
+      .write_file(&file_path1, "text1")
+      .write_file(&file_path2, "text2")
+      .write_file(&file_path3, "text3")
+      .with_default_config(|c| {
+        c.add_excludes("/file1.txt").add_remote_wasm_plugin();
+      })
+      .initialize()
+      .build();
+
+    run_test_cli(vec!["fmt", "--excludes", "/file2.txt"], &environment).unwrap();
+
+    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
+    assert_eq!(environment.read_file(&file_path1).unwrap(), "text1");
+    assert_eq!(environment.read_file(&file_path2).unwrap(), "text2");
+    assert_eq!(environment.read_file(&file_path3).unwrap(), "text3_formatted");
+  }
+
+  #[test]
+  fn should_override_config_excludes_with_cli_excludes_override() {
     let file_path1 = "/file1.txt";
     let file_path2 = "/file2.txt";
     let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
@@ -1187,7 +1258,7 @@ mod test {
       .initialize()
       .build();
 
-    run_test_cli(vec!["fmt", "--excludes", "/file2.txt"], &environment).unwrap();
+    run_test_cli(vec!["fmt", "--excludes-override", "/file2.txt"], &environment).unwrap();
 
     assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
     assert_eq!(environment.read_file(&file_path1).unwrap(), "text1_formatted");
@@ -1195,7 +1266,7 @@ mod test {
   }
 
   #[test]
-  fn should_support_clearing_config_excludes_with_cli_excludes_arg() {
+  fn should_support_clearing_config_excludes_with_cli_excludes_override_arg() {
     let file_path1 = "/file1.txt";
     let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
       .write_file(&file_path1, "text1")
@@ -1205,7 +1276,7 @@ mod test {
       .initialize()
       .build();
 
-    run_test_cli(vec!["fmt", "--excludes="], &environment).unwrap();
+    run_test_cli(vec!["fmt", "--excludes-override="], &environment).unwrap();
 
     assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
     assert_eq!(environment.read_file(&file_path1).unwrap(), "text1_formatted");
@@ -1228,7 +1299,51 @@ mod test {
   }
 
   #[test]
-  fn should_override_config_includes_and_excludes_with_cli() {
+  fn should_combine_config_excludes_with_cli_args() {
+    let file_path1 = "/file1.txt";
+    let file_path2 = "/sub/file2.txt";
+    let file_path3 = "/sub/file3.txt";
+    let file_path4 = "/sub/file4.txt";
+    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
+      .write_file(&file_path1, "text1")
+      .write_file(&file_path2, "text2")
+      .write_file(&file_path3, "text3")
+      .write_file(&file_path4, "text4")
+      .with_default_config(|c| {
+        c.add_includes("/sub/**/*.txt").add_excludes("/sub/file4.txt").add_remote_wasm_plugin();
+      })
+      .initialize()
+      .build();
+    run_test_cli(vec!["fmt", "--excludes", "/sub/file3.txt"], &environment).unwrap();
+
+    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
+    assert_eq!(environment.read_file(&file_path1).unwrap(), "text1");
+    assert_eq!(environment.read_file(&file_path2).unwrap(), "text2_formatted");
+    assert_eq!(environment.read_file(&file_path3).unwrap(), "text3");
+    assert_eq!(environment.read_file(&file_path4).unwrap(), "text4");
+  }
+
+  #[test]
+  fn should_format_intersect_of_config_includes_and_cli_includes() {
+    let file_path1 = "/sub/file1.txt";
+    let file_path2 = "/sub/file2.txt";
+    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
+      .write_file(&file_path1, "text1")
+      .write_file(&file_path2, "text2")
+      .with_default_config(|c| {
+        c.add_includes("/sub/**/*.txt").add_remote_wasm_plugin();
+      })
+      .initialize()
+      .build();
+    run_test_cli(vec!["fmt", "/sub/file2.txt"], &environment).unwrap();
+
+    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
+    assert_eq!(environment.read_file(&file_path1).unwrap(), "text1");
+    assert_eq!(environment.read_file(&file_path2).unwrap(), "text2_formatted");
+  }
+
+  #[test]
+  fn should_override_config_includes_and_excludes_with_cli_overrides() {
     let file_path1 = "/file1.txt";
     let file_path2 = "/file2.txt";
     let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
@@ -1239,7 +1354,11 @@ mod test {
       })
       .initialize()
       .build();
-    run_test_cli(vec!["fmt", "/file1.txt", "--excludes", "/file2.txt"], &environment).unwrap();
+    run_test_cli(
+      vec!["fmt", "--includes-override", "/file1.txt", "--excludes-override", "/file2.txt"],
+      &environment,
+    )
+    .unwrap();
 
     assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
     assert_eq!(environment.read_file(&file_path1).unwrap(), "text1_formatted");
@@ -1465,7 +1584,7 @@ mod test {
 
     let result = run_test_cli(vec!["fmt", "--incremental"], &environment).err().unwrap();
 
-    assert_eq!(result.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(result.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![concat!(
@@ -1485,7 +1604,7 @@ mod test {
 
     let result = run_test_cli(vec!["fmt", "--incremental"], &environment).err().unwrap();
 
-    assert_eq!(result.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(result.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![concat!(
@@ -1737,7 +1856,6 @@ mod test {
 
   #[test]
   fn should_format_for_stdin_with_absolute_paths() {
-    // it should not output anything when downloading plugins
     let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_plugin()
       .with_default_config(|c| {
         c.add_includes("/src/**.*").add_remote_wasm_plugin();
@@ -1750,12 +1868,17 @@ mod test {
     run_test_cli_with_stdin(vec!["fmt", "--stdin", "/file.txt"], &environment, test_std_in.clone()).unwrap();
     assert_eq!(environment.take_stdout_messages(), vec!["text"]);
 
-    // make it matching on the cli
-    run_test_cli_with_stdin(vec!["fmt", "--stdin", "/file.txt", "--", "**/*.txt"], &environment, test_std_in.clone()).unwrap();
+    // matching file
+    run_test_cli_with_stdin(vec!["fmt", "--stdin", "/src/file.txt"], &environment, test_std_in.clone()).unwrap();
     assert_eq!(environment.take_stdout_messages(), vec!["text_formatted"]);
 
-    // matching file
-    run_test_cli_with_stdin(vec!["fmt", "--stdin", "/src/file.txt"], &environment, test_std_in).unwrap();
+    // override what's in the config when overriding
+    run_test_cli_with_stdin(
+      vec!["fmt", "--stdin", "/file.txt", "--includes-override", "**/*.txt"],
+      &environment,
+      test_std_in,
+    )
+    .unwrap();
     assert_eq!(environment.take_stdout_messages(), vec!["text_formatted"]);
   }
 
@@ -1979,7 +2102,7 @@ mod test {
 
     let error_message = run_test_cli(vec!["fmt", "**/*.txt"], &environment).err().unwrap();
 
-    assert_eq!(error_message.to_string(), "Had 1 error(s) formatting.");
+    assert_eq!(error_message.to_string(), "Had 1 error formatting.");
     assert_eq!(
       environment.take_stderr_messages(),
       vec![
@@ -2028,6 +2151,34 @@ mod test {
     assert_eq!(environment.read_file(&file_path4).unwrap(), "text_formatted");
   }
 
+  #[test]
+  fn should_not_error_nested_config_no_matching_files_in_scope_cli_args() {
+    let file_path1 = "/sub_dir/file.txt";
+    let file_path2 = "/sub_dir/sub_dir/file.txt";
+    let file_path3 = "/sub_dir/more/ignored.txt_ps";
+    let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_and_process_plugin()
+      .with_local_config("/sub_dir/dprint.json", |config| {
+        config.add_remote_wasm_plugin();
+      })
+      .with_local_config("/sub_dir/more/dprint.json", |config| {
+        config.add_remote_process_plugin();
+      })
+      .write_file(&file_path1, "here1")
+      .write_file(&file_path2, "here2")
+      .write_file(&file_path3, "here3")
+      .build();
+    // previously this was erroring in the sub directory
+    run_test_cli(vec!["fmt", "**/*.txt"], &environment).unwrap();
+    assert_eq!(environment.take_stdout_messages(), vec![get_plural_formatted_text(2)]);
+    assert_eq!(environment.read_file(&file_path1).unwrap(), "here1_formatted");
+    assert_eq!(environment.read_file(&file_path2).unwrap(), "here2_formatted");
+    assert_eq!(environment.read_file(&file_path3).unwrap(), "here3");
+
+    // now try with a pattern that doesn't match any file in any scope and it should error
+    let err = run_test_cli(vec!["fmt", "**/*.no_matching"], &environment).unwrap_err();
+    assert_no_files_found(&err, &environment);
+  }
+
   #[test]
   fn should_error_no_files_sub_dir_config() {
     let file_path1 = "/file.txt";
@@ -2040,8 +2191,32 @@ mod test {
     let err = run_test_cli(vec!["fmt"], &environment).err().unwrap();
     assert_eq!(
       err.to_string(),
-      "No files found to format with the specified plugins at /sub_dir. You may want to try using `dprint output-file-paths` to see which files it's finding."
+      "No files found to format with the specified plugins at /sub_dir. You may want to try using `dprint output-file-paths` to see which files it's finding or run with `--allow-no-files`."
     );
     err.assert_exit_code(14);
   }
+
+  #[test]
+  fn should_error_format_to_empty() {
+    // this is to prevent a plugin accidentally formatting a file to an empty file
+    let file_path1 = "/file.txt";
+    let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_plugin()
+      .with_local_config("/dprint.json", |config| {
+        config.add_remote_wasm_plugin();
+      })
+      .write_file(&file_path1, &format!("format_to_empty {}", "a".repeat(400)))
+      .build();
+    let err = run_test_cli(vec!["fmt"], &environment).err().unwrap();
+    assert_eq!(err.to_string(), "Had 1 error formatting.");
+    err.assert_exit_code(1);
+    assert_eq!(
+      environment.take_stderr_messages(),
+      vec![concat!(
+        "Error formatting /file.txt. Message: The original file text was greater than 300 characters, ",
+        "but the formatted text was empty. Most likely this is a bug in the plugin and the dprint CLI has ",
+        "prevented the plugin from formatting the file to an empty file. Please report this scenario."
+      )
+      .to_string()]
+    );
+  }
 }
