@@ -11,9 +11,7 @@ use std::path::Path;
 use std::path::PathBuf;
 use std::sync::Arc;
 use std::time::SystemTime;
-use sysinfo::CpuExt;
 use sysinfo::System;
-use sysinfo::SystemExt;
 
 use dprint_core::async_runtime::async_trait;
 
@@ -58,9 +56,7 @@ impl RealEnvironment {
       log_level: options.log_level,
     }));
     let progress_bars = ProgressBars::new(&logger).map(Arc::new);
-    let url_downloader = Arc::new(RealUrlDownloader::new(progress_bars.clone(), logger.clone(), |env_var_name| {
-      std::env::var(env_var_name).ok()
-    })?);
+    let url_downloader = Arc::new(RealUrlDownloader::new(progress_bars.clone(), logger.clone())?);
     let environment = RealEnvironment {
       url_downloader,
       logger,
@@ -240,8 +236,8 @@ impl Environment for RealEnvironment {
     self.logger.log(text, "dprint");
   }
 
-  fn log_machine_readable(&self, text: &str) {
-    self.logger.log_machine_readable(text);
+  fn log_machine_readable(&self, bytes: &[u8]) {
+    self.logger.log_machine_readable(bytes);
   }
 
   fn log_stderr_with_context(&self, text: &str, context_name: &str) {
@@ -357,7 +353,7 @@ impl Environment for RealEnvironment {
     };
 
     // wait a duration that allows getting a more accurate cpu usage
-    tokio::time::sleep(System::MINIMUM_CPU_UPDATE_INTERVAL).await;
+    tokio::time::sleep(sysinfo::MINIMUM_CPU_UPDATE_INTERVAL).await;
 
     dprint_core::async_runtime::spawn_blocking(move || {
       let mut system = system.lock();
