@@ -1,5 +1,7 @@
+use std::cell::RefCell;
 use std::collections::BTreeMap;
 use std::hash::Hasher;
+use std::path::Path;
 use std::path::PathBuf;
 use std::rc::Rc;
 use std::sync::Arc;
@@ -36,6 +38,8 @@ use crate::environment::Environment;
 use crate::paths::get_and_resolve_file_paths;
 use crate::paths::get_file_paths_by_plugins;
 use crate::paths::FilesPathsByPlugins;
+use crate::paths::NoFilesFoundError;
+use crate::patterns::FileMatcher;
 use crate::plugins::output_plugin_config_diagnostics;
 use crate::plugins::FormatConfig;
 use crate::plugins::InitializedPlugin;
@@ -138,7 +142,7 @@ impl PluginWithConfig {
 
 pub struct InitializedPluginWithConfigFormatRequest {
   pub file_path: PathBuf,
-  pub file_text: String,
+  pub file_bytes: Vec<u8>,
   pub range: FormatRange,
   pub override_config: ConfigKeyMap,
   pub on_host_format: HostFormatCallback,
@@ -184,7 +188,7 @@ impl InitializedPluginWithConfig {
       .instance
       .format_text(InitializedPluginFormatRequest {
         file_path: request.file_path,
-        file_text: request.file_text,
+        file_text: request.file_bytes,
         range: request.range,
         config: self.plugin.format_config.clone(),
         override_config: request.override_config,
@@ -201,6 +205,7 @@ pub struct PluginsScope<TEnvironment: Environment> {
   pub plugins: IndexMap<String, Rc<PluginWithConfig>>,
   pub plugin_name_maps: PluginNameResolutionMaps,
   global_config_diagnostics: Vec<GlobalConfigDiagnostic>,
+  cached_editor_file_matcher: RefCell<Option<FileMatcher>>,
 }
 
 impl<TEnvironment: Environment> PluginsScope<TEnvironment> {
@@ -218,6 +223,7 @@ impl<TEnvironment: Environment> PluginsScope<TEnvironment> {
       plugin_name_maps,
       plugins: plugins.into_iter().map(|p| (p.name().to_string(), p)).collect(),
       global_config_diagnostics,
+      cached_editor_file_matcher: Default::default(),
     })
   }
 
@@ -314,19 +320,40 @@ impl<TEnvironment: Environment> PluginsScope<TEnvironment> {
     Rc::new(move |host_request| scope.format(host_request))
   }
 
+  pub fn can_format_for_editor(&self, file_path: &Path) -> bool {
+    let mut file_matcher_borrow = self.cached_editor_file_matcher.borrow_mut();
+    if file_matcher_borrow.is_none() {
+      let Some(config) = &self.config else {
+        return false;
+      };
+      let matcher = match FileMatcher::new(config, &FilePatternArgs::default(), &config.base_path) {
+        Ok(matcher) => matcher,
+        Err(err) => {
+          log_warn!(self.environment, "Error creating file matcher: {}", err);
+          return false;
+        }
+      };
+      file_matcher_borrow.replace(matcher);
+    }
+    match file_matcher_borrow.as_ref() {
+      Some(file_matcher) => file_matcher.matches_and_dir_not_ignored(file_path),
+      None => false, // should never happen
+    }
+  }
+
   pub fn format(self: &Rc<Self>, request: HostFormatRequest) -> LocalBoxFuture<'static, FormatResult> {
     let plugin_names = self.plugin_name_maps.get_plugin_names_from_file_path(&request.file_path);
     log_debug!(
       self.environment,
       "Host formatting {} - File length: {} - Plugins: [{}] - Range: {:?}",
       request.file_path.display(),
-      request.file_text.len(),
+      request.file_bytes.len(),
       plugin_names.join(", "),
       request.range,
     );
     let scope = self.clone();
     async move {
-      let mut file_text = request.file_text;
+      let mut file_text = request.file_bytes;
       let mut had_change = false;
       for plugin_name in plugin_names {
         let plugin = scope.get_plugin(&plugin_name);
@@ -335,7 +362,7 @@ impl<TEnvironment: Environment> PluginsScope<TEnvironment> {
             let result = initialized_plugin
               .format_text(InitializedPluginWithConfigFormatRequest {
                 file_path: request.file_path.clone(),
-                file_text: file_text.clone(),
+                file_bytes: file_text.clone(),
                 range: request.range.clone(),
                 override_config: request.override_config.clone(),
                 on_host_format: scope.create_host_format_callback(),
@@ -358,25 +385,50 @@ impl<TEnvironment: Environment> PluginsScope<TEnvironment> {
   }
 }
 
-pub struct PluginsScopeAndPathsCollection<TEnvironment: Environment>(Vec<PluginsScopeAndPaths<TEnvironment>>);
+pub struct PluginsScopeAndPathsCollection<TEnvironment: Environment> {
+  environment: TEnvironment,
+  inner: Vec<PluginsScopeAndPaths<TEnvironment>>,
+}
 
 impl<TEnvironment: Environment> PluginsScopeAndPathsCollection<TEnvironment> {
   pub fn ensure_valid_for_cli_args(&self, cli_args: &CliArgs) -> Result<()> {
-    for scope in &self.0 {
+    for scope in &self.inner {
       scope.scope.ensure_valid_for_cli_args(cli_args)?;
-      if let Some(config) = scope.scope.config.as_ref() {
-        scope.file_paths_by_plugins.ensure_not_empty(&config.base_path)?;
+    }
+
+    // ensure we found some files
+    if !cli_args.sub_command.allow_no_files() {
+      let has_cli_file_patterns = cli_args.sub_command.file_patterns().map(|p| !p.include_patterns.is_empty()).unwrap_or(false);
+      // when the user specifies a pattern on the command line, just ensure that one scope matched
+      if has_cli_file_patterns {
+        let all_empty = self.iter().all(|s| s.file_paths_by_plugins.is_empty());
+        if all_empty {
+          return Err(
+            NoFilesFoundError {
+              base_path: self.environment.cwd(),
+            }
+            .into(),
+          );
+        }
+      } else {
+        // if no args specified then ensure all scopes have files
+        for scope in &self.inner {
+          if let Some(config) = scope.scope.config.as_ref() {
+            scope.file_paths_by_plugins.ensure_not_empty(&config.base_path)?;
+          }
+        }
       }
     }
+
     Ok(())
   }
 
   pub fn iter(&self) -> impl Iterator<Item = &PluginsScopeAndPaths<TEnvironment>> {
-    self.0.iter()
+    self.inner.iter()
   }
 
   pub fn into_iter(self) -> impl Iterator<Item = PluginsScopeAndPaths<TEnvironment>> {
-    self.0.into_iter()
+    self.inner.into_iter()
   }
 }
 
@@ -422,7 +474,10 @@ impl<'a, TEnvironment: Environment> PluginsAndPathsResolver<'a, TEnvironment> {
       result.extend(self.resolve_for_sub_config(config_file_path, &config, root_config_path).await?);
     }
 
-    Ok(PluginsScopeAndPathsCollection(result))
+    Ok(PluginsScopeAndPathsCollection {
+      environment: self.environment.clone(),
+      inner: result,
+    })
   }
 
   fn resolve_for_sub_config(
@@ -477,6 +532,7 @@ pub async fn get_plugins_scope_from_args<TEnvironment: Environment>(
       plugin_name_maps: Default::default(),
       plugins: Default::default(),
       global_config_diagnostics: Default::default(),
+      cached_editor_file_matcher: Default::default(),
     }),
   }
 }
