@@ -6,7 +6,7 @@ use crossterm::event::KeyCode;
 use super::Logger;
 use super::LoggerRefreshItemKind;
 use super::LoggerTextItem;
-use crate::utils::terminal::read_terminal_event;
+use crate::utils::terminal::read_terminal_key_press;
 
 struct SelectData<'a> {
   prompt: &'a str,
@@ -27,7 +27,7 @@ pub fn show_select(logger: &Logger, context_name: &str, prompt: &str, item_hangi
     let text_items = render_select(&data);
     logger.set_refresh_item(LoggerRefreshItemKind::Selection, text_items);
 
-    if let Event::Key(key_event) = read_terminal_event()? {
+    if let Event::Key(key_event) = read_terminal_key_press()? {
       match &key_event.code {
         KeyCode::Up => {
           if data.active_index == 0 {
