@@ -7,14 +7,17 @@ mod file_text;
 mod get_bytes_hash;
 mod get_difference;
 mod glob;
+mod lax_single_process_fs_flag;
 mod logging;
 mod path_source;
 mod pretty_print_json_text;
 mod process;
 mod resolve_url_or_file_path;
 mod stdin_reader;
+mod sync;
 mod table_text;
 mod terminal;
+mod unsync;
 mod update_checker;
 mod url;
 
@@ -28,12 +31,15 @@ pub use file_text::*;
 pub use get_bytes_hash::*;
 pub use get_difference::*;
 pub use glob::*;
+pub use lax_single_process_fs_flag::*;
 pub use logging::*;
 pub use path_source::*;
 pub use pretty_print_json_text::*;
 pub use process::*;
 pub use resolve_url_or_file_path::*;
 pub use stdin_reader::*;
+pub use sync::*;
 pub use table_text::*;
 pub use terminal::*;
+pub use unsync::*;
 pub use update_checker::*;
