@@ -7,7 +7,7 @@ use super::PathSource;
 use crate::environment::CanonicalizedPathBuf;
 use crate::environment::Environment;
 
-#[derive(Clone, PartialEq, Eq, Debug)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct ResolvedPath {
   pub file_path: CanonicalizedPathBuf,
   pub source: PathSource,
